angular.module('backupCopyMedia', ['ngDialog', 'angulartics', 'angulartics.google.analytics'])
.service('mediaService', ['$analytics', 'ngDialog', '$rootScope', function($analytics, ngDialog, $rootScope) {

    this.prepareTarget = function(target, sid, load) {
        $analytics && $analytics.eventTrack('Prepare Target', {  category: 'Configure', label: 'Target' });
        var url = '/api/archive/media/prepare/';
        var obj = {};
        var now = new Date();
        obj.label = "tgt_" + now.getDate() + "_" + now.getHours();
        if (target) {
            url += target.name + '/?sid=' + sid;
            if (target.archive) {
                obj.mount = true;
            }
        }
        obj = JSON.stringify(obj);
        return PHD.Ajax.put(url, obj, load, this.handleMediaError);
    };

    this.getSets = function(target, sid, load) {
        $analytics && $analytics.eventTrack('Prepare Target', {  category: 'Configure', label: 'Target' });
        var url = '/api/archive/media/sets/';
        if (target) {
            url += target.name + '/?sid=' + sid;
        }
        return PHD.Ajax.get(url, null, this.handleMediaError);
    };

    this.handleMediaError = function(jqXHR, textStatus, errorThrown) {
        if(jqXHR.status === 500) {
            var data = jqXHR.responseJSON;
            var error = data;
            if (data !== undefined && data.result !== undefined && data.result[0] !== undefined) {
                error = data.result[0].message;
                console.log("The error is:" + error);
            }
            var scope = $rootScope.$new();
            ngDialog.open({
                dialogType:'Error',
                modelDialogId:'ErrorDialog',
                dialogMessage: error,
                scope:scope,
                onConfirmOkButtonClick:'onConfirmError()'
            });
            scope.onConfirmError = function () {
                ngDialog.close('ErrorDialog');
            };
        } else {
            PHD.Ajax.ajaxError(jqXHR, textStatus, errorThrown);
        }
    };

}])
.controller('eraseMediaCtrl', ['$scope', '$rootScope', '$http','ngDialog', 'mediaService', function($scope, $rootScope, $http, ngDialog, mediaService) {

        $scope.target = $scope.ngDialogData.target;
        $scope.sid = $scope.ngDialogData.appliance_id;
        $scope.showSets = false;

        $scope.confirmErase = function(){
            $scope.showSets = false;
            var load = PHD.showLoadingIndicator('body', true, "Erasing Target...");
            var resp = mediaService.prepareTarget($scope.target, $scope.sid, load);
            resp.done(function (data) {
                $scope.closeThisDialog();
            });
        };

        $scope.getSets = function() {
            console.log($scope.target, $scope.sid);
            var resp = mediaService.getSets($scope.target, $scope.sid, null);
            resp.done(function (data) {
                var sets = data.sets;
                $scope.setCount = 0;
                if (sets !== undefined && sets.length > 0) {
                    $scope.setCount = sets.length;
                    $scope.firstSet = sets[0];
                    $scope.lastSet = sets[sets.length - 1];
                    $scope.dateRangeString = $scope.setCount > 0 ? ", ranging from " + $scope.firstSet.date + " to " + $scope.lastSet.date + "." : ".";
                }
                $scope.showSets = true;
                setTimeout(function () {
                    $scope.$apply();
                }, 250);
            });
        };

}])
.controller('prepareMediaCtrl', ['$scope', '$rootScope', '$http','ngDialog', 'mediaService', function($scope, $rootScope, $http, ngDialog, mediaService) {

    $scope.target = $scope.ngDialogData.target;
    $scope.sid = $scope.ngDialogData.appliance_id;

    $scope.confirmPrepare = function(){

        console.log($scope.target, $scope.sid);
        var load = PHD.showLoadingIndicator('body', true, "Preparing Target...");
        var resp = mediaService.prepareTarget($scope.target, $scope.sid, load);
        resp.done(function (data) {
            $scope.closeThisDialog();
        });
    };

}]);